@@ -2,6 +2,7 @@ from pathlib import Path
 from python_on_whales import DockerClient
 from jsonschema import validate
 import collections.abc
+import uuid
 import os
 import re
 import argparse
@@ -12,7 +13,7 @@ import tomli
 import tomli_w
 import shutil
 
-from flowui.scripts.build_docker_images_operators import build_images_from_code_repository
+from flowui.scripts.build_docker_images_operators import build_images_from_operators_repository
 from flowui.scripts.create_docker_compose_file import create_docker_compose_file
 from flowui.scripts.run_operator_docker import run_operator as run_operator_in_docker
 from flowui.scripts.run_operator_bash import run_operator as run_operator_in_bash
@@ -33,28 +34,179 @@ def dict_deep_update(d, u):
 
 
 class CommandLineInterface:
+
     def __init__(self):
         self.logger = get_configured_logger(self.__class__.__name__)
         self.config_required_fields = {
-            "PROJECT_NAME": None,
+            "REPOSITORY_NAME": None,
             "FLOWUI_DEPLOY_MODE": None,
             "VOLUME_MOUNT_PATH_HOST": None,
-            "CODE_REPOSITORY_SOURCE": None,
+            "OPERATORS_REPOSITORY_SOURCE": None,
             "GITHUB_REPOSITORY_NAME": None,
         }
 
         self.required_env_vars_validators = {
             "GITHUB_ACCESS_TOKEN": {
-                "depends": lambda arg: arg.get('CODE_REPOSITORY_SOURCE') == 'github',
+                "depends": lambda arg: arg.get('OPERATORS_REPOSITORY_SOURCE') == 'github',
                 "validator_func": self._validate_github_token
             }
         }
         self.args = self._parse_arguments()
+    
+
+    @staticmethod
+    def _parse_arguments() -> argparse.Namespace:
+        """Parse user CLI arguments and actions
+
+        The accepted actions are:
+            - organize: Organize the Operators repository into a FlowUI structure.
+            - run: Create docker-compose file and run the FlowUI platform locally.
+            - run-local-dev: Create docker-compose file and run the FlowUI platform locally in development mode.
+            - stop: Stop the FlowUI platform.
+            - create-compose-file: Create a docker-compose file for the FlowUI platform.
+            - run-operator-docker: Run an operator using docker.
+            - run-operator-bash: Run an operator using bash.
+
+        The accepted arguments are:
+            - operators_repository_path: Path to the Operators repository
+
+        Returns:
+            argparse.Namespace: Parsed arguments
+        """
+        parser = argparse.ArgumentParser(
+            description='CLI for FlowUI',
+        )
+
+        action_choices = [
+            'organize', 
+            'run', 
+            'stop', 
+            'create-compose-file', 
+            'run-local-dev', 
+            'run-operator-docker', 
+            'run-operator-bash', 
+            'create-operators-repository'
+        ]
+        parser.add_argument(
+            'action', 
+            metavar='Action', 
+            type=str, 
+            choices=action_choices,
+            help=f'action to be executed: {" | ".join(action_choices)}'
+        )
+
+        parser.add_argument(
+            "--operators_repository_path",
+            type=str,
+            default="./",
+            help="Path to Operators repository"
+        )
+
+        parser.add_argument(
+            "--build-images",
+            action='store_true',
+            help="Build Docker images"
+        )
+
+        parser.add_argument(
+            "--publish-images",
+            action='store_true',
+            help="Publish Docker images to Docker Hub"
+        )
+
+        args = parser.parse_args()
+
+        return args
+    
+
+    def run(self) -> None:
+        """
+        Run FlowUI using local deploy scope.
+        This will create a docker-compose.yaml file and run it.
+        """
+        self._validate_repository_structure()
+        self._create_mnt_required_folders()
+        self.create_docker_compose_file()
+        self.docker = DockerClient(compose_files=["docker-compose.yaml"])
+        self.docker.compose.up()
+
+
+    def run_local_dev(self) -> None:
+        """
+        Run FlowUI using local development environment scope.
+        This will create a docker-compose.yaml file and run it.
+        """ 
+        self._validate_repository_structure()
+        if not os.environ.get('FLOWUI_PATH_HOST'):
+            os.environ['FLOWUI_PATH_HOST'] = str(Path('../flowui').resolve())
+        self._create_mnt_required_folders()
+        self.create_docker_compose_file(run_scope="local-dev")
+        self.docker = DockerClient(compose_files=["docker-compose.yaml"])
+        self.docker.compose.up()
+
+
+    def stop_compose(self) -> None:
+        """Stop FlowUI. From the running docker compose, stop and remove the running containers"""
+        compose = Path("docker-compose.yaml")
+        if not compose.is_file():
+            raise Exception("docker-compose.yaml file not found")
+        try:
+            self.logger.info("Stopping docker-compose...")
+            self.docker = DockerClient(compose_files=["docker-compose.yaml"])
+            self.docker.compose.down()
+        except Exception as e: # work on python 3.x
+            self.logger.info('Failed to stop compose processes: '+ str(e))
+        # TODO - add docker stop and docker rm
+
+
+    def _validate_repository_structure(self) -> None:
+        """
+        Validate the Operators repository structure.
+        The basic structure must contain:
+        - config.toml
+        - operators/
+        - dependencies/
+        """
+        self.operators_path = Path(self.args.operators_repository_path) / "operators"
+        self.dependencies_path = Path(self.args.operators_repository_path) / "dependencies"
+        self.organized_flowui_path = Path(self.args.operators_repository_path) / ".flowui/"
+        if not self.organized_flowui_path.is_dir():
+            self.organized_flowui_path.mkdir(parents=True, exist_ok=True)
+        
+        # Validating config
+        self.config_path = Path(self.args.operators_repository_path) / 'config.toml'
+        if not self.config_path.is_file():
+            self.logger.error("Missing config file")
+            raise FileNotFoundError("Missing config file")
+
+        with open(self.config_path, "rb") as f:
+            self.config_dict = tomli.load(f)
+
+        self._validate_config()
+        self._validate_env_vars()
+
+        operators_repository = Path(self.args.operators_repository_path)
+        if not operators_repository.is_dir():
+            self.logger.error("Operators repository path does not exist")
+            raise Exception("Operators repository path does not exist")
+
+        if not (operators_repository / 'config.toml').is_file():
+            self.logger.error("config.toml file does not exist")
+            raise Exception("config.toml file does not exist")
+
+        if not (operators_repository / 'operators').is_dir():
+            self.logger.error("Operators directory does not exist")
+            raise Exception("Operators directory does not exist")
+        
+        if not (operators_repository / 'dependencies').is_dir():
+            self.logger.error("Dependencies directory does not exist")
+            raise Exception("Dependencies directory does not exist")
+        os.environ['OPERATORS_REPOSITORY_PATH_HOST'] = str(operators_repository)
+
 
     def _validate_config(self) -> None:
         """
-        Validate user config.toml file and save it to config_dict and 
-        as environment variables to be used by the docker-compose file
+        Validate user config.toml file and save it to config_dict and as environment variables to be used by the docker-compose file
         """
         required_fields = list(self.config_required_fields.keys()).copy()
         required_secrets = list()
@@ -62,7 +214,7 @@ class CommandLineInterface:
         for section in sections:
             for key, value in self.config_dict.get(section).items():
                 # Check if OPERATORS_SECRETS exist in environment
-                if section == "project" and key == "OPERATORS_SECRETS":
+                if section == "repository" and key == "OPERATORS_SECRETS":
                     for v in value:
                         if not os.getenv(v, None):
                             required_secrets.append(v)
@@ -81,101 +233,12 @@ class CommandLineInterface:
             missing = '\n'.join(required_secrets)
             self.logger.warning(f"Missing required operators secrets. These shold be defined in your ENV: \n{missing}") 
 
-    def _validate_project_structure(self) -> None:
-        """
-        Validate user project structure.
-        The basic structure must be:
-        - project/
-            - config.toml
-            - operators/
-            - dependencies/
-        """
-        self.operators_path = Path(self.args.code_repository_path) / "operators"
-        self.dependencies_path = Path(self.args.code_repository_path) / "dependencies"
-        self.organized_flowui_path = Path(self.args.code_repository_path) / ".flowui/"
-        if not self.organized_flowui_path.is_dir():
-            self.organized_flowui_path.mkdir(parents=True, exist_ok=True)
-        
-        # Validating config
-        self.config_path = Path(self.args.code_repository_path) / 'config.toml'
-        if not self.config_path.is_file():
-            self.logger.error("Missing config file")
-            raise FileNotFoundError("Missing config file")
-
-        with open(self.config_path, "rb") as f:
-            self.config_dict = tomli.load(f)
-
-        self._validate_config()
-        self._validate_env_vars()
-
-        code_repository = Path(self.args.code_repository_path)
-        if not code_repository.is_dir():
-            self.logger.error("Code repository path does not exist")
-            raise Exception("Code repository path does not exist")
-
-        if not (code_repository / 'config.toml').is_file():
-            self.logger.error("config.toml file does not exist")
-            raise Exception("config.toml file does not exist")
-
-        if not (code_repository / 'operators').is_dir():
-            self.logger.error("Operators directory does not exist")
-            raise Exception("Operators directory does not exist")
-        
-        if not (code_repository / 'dependencies').is_dir():
-            self.logger.error("Dependencies directory does not exist")
-            raise Exception("Dependencies directory does not exist")
-        os.environ['CODE_REPOSITORY_PATH_HOST'] = str(code_repository)
-        return True
-
-    @staticmethod
-    def _parse_arguments() -> argparse.Namespace:
-        """Parse user CLI arguments and actions
-
-        The accepted actions are:
-            - organize: Organize the code repository into a FlowUI structure.
-            - run: Create docker-compose file and run the FlowUI project.
-            - run-local-dev: Create docker-compose file and run the FlowUI project in development mode.
-            - stop: Stop the FlowUI project.
-            - build-docker-images: Build docker images for the operators in the code repository.
-            - create-compose-file: Create a docker-compose file for the FlowUI project.
-            - run-operator-docker: Run an operator using docker.
-            - run-operator-bash: Run an operator using bash.
-
-        The accepted arguments are:
-            - code_repository_path: Path to the code repository
-
-        Returns:
-            argparse.Namespace: Parsed arguments
-        """
-        parser = argparse.ArgumentParser(
-            description='CLI for FlowUI',
-        )
-
-        action_choices = ['organize', 'run', 'stop', 'build-docker-images', 'create-compose-file', 'run-local-dev', 'run-operator-docker', 'run-operator-bash', 'create-project']
-        parser.add_argument(
-            'action', 
-            metavar='Action', 
-            type=str, 
-            choices=action_choices,
-            help=f'action to be executed: {" | ".join(action_choices)}'
-        )
-
-        parser.add_argument(
-            "--code_repository_path",
-            type=str,
-            default="./",
-            help="Path to code repository"
-        )
-
-        args = parser.parse_args()
-
-        return args
 
     def _validate_env_vars(self) -> None:
         """
-            Validate user environment variables.
-            The accepted variables are:
-                - GITHUB_ACCESS_TOKEN: Token to access GitHub API.
+        Validate user environment variables.
+        The accepted variables are:
+            - GITHUB_ACCESS_TOKEN: Token to access GitHub API.
         """
         # Set AIRFLOW_UID from host user id 
         # https://airflow.apache.org/docs/apache-airflow/stable/start/docker.html#setting-the-right-airflow-user
@@ -197,21 +260,25 @@ class CommandLineInterface:
                 new_var = input(f"Wrong {var} format. Enter a new value: ")
             os.environ[var] = new_var
 
+
     @staticmethod
     def _set_config_as_env(key: Union[str, int], value: Union[str, int, float]):
-        """Set a env variable with the key and value.
+        """
+        Set an ENV variable with the key and value.
 
         Args:
-            key (Union[str, int]): Env var name
-            value (Union[str, int, float]): Env var value
+            key (Union[str, int]): ENV var name
+            value (Union[str, int, float]): ENV var value
         """
         key = str(key).strip().upper()
         os.environ[key] = str(value)
 
+
     @staticmethod
     def _validate_github_token(token: str) -> bool:
-        """Validate GITHUB_ACCESS_TOKEN
-        By now it is only accepting only the ghp token.
+        """
+        Validate GITHUB_ACCESS_TOKEN
+        By now it is only accepting the ghp token.
 
         Args:
             token (str): Github access token (ghp)
@@ -225,9 +292,10 @@ class CommandLineInterface:
             return True
         return False
 
-    def _validate_code_repository(self) -> None:
+
+    def _validate_operators_repository(self) -> None:
         """
-        Validate user code repository structure.
+        Validate the Operators repository structure.
         """
         dependencies_files = [f.name for f in self.dependencies_path.glob("*")]
         name_errors = list()
@@ -269,25 +337,33 @@ class CommandLineInterface:
         if len(missing_dependencies_errors) > 0:
             raise Exception("\n" + "\n".join(missing_dependencies_errors))
 
-    def build_docker_images(self) -> None:
-        """Convenience function to run build Docker images from code_repository dependencies"""
+
+    def _build_docker_images(self) -> None:
+        """Convenience function to build Docker images from the repository dependencies and publish them to Docker Hub"""
         self.logger.info("Building Docker images and generating map file...")
-        build_images_from_code_repository(code_repository=self.args.code_repository_path)
+        updated_dependencies_map = build_images_from_operators_repository(
+            operators_repository=self.args.operators_repository_path,
+            publish=self.args.publish_images
+        )
+        return updated_dependencies_map
+
 
     def create_docker_compose_file(self, run_scope="deploy-local")-> None:
-        """Convenience function to create docker-compose.yaml file in the code_repository directory.
+        """
+        Convenience function to create docker-compose.yaml file in the operators_repository directory.
 
         Args:
             run_scope (str): Scope of the run. Default is deploy-local. Options are (deploy-local, local-dev)
         """
         self.logger.info("Creating docker-compose.yaml file...")
         create_docker_compose_file(
-            code_repository_path=self.args.code_repository_path,
+            repository_path=self.args.operators_repository_path,
             run_scope=run_scope,
-            project_config=self.config_dict
+            repository_config=self.config_dict
         )
         self.logger.info("docker-compose.yaml file created successfully!")
 
+
     def _create_mnt_required_folders(self):
         """Function to create required folders in user mount path
         Required folders are:
@@ -295,7 +371,7 @@ class CommandLineInterface:
         ----|logs
         ----|plugins
         ----| dags 
-        - code_repository
+        - operators_repository
         --| operators
         --| workflows
         - datasets
@@ -323,16 +399,16 @@ class CommandLineInterface:
         if not airflow_dags_path.exists():
             airflow_dags_path.mkdir(parents=True, exist_ok=True)
 
-        # Code repository folders
-        code_repository_path = base_path / "code_repository"
-        if not code_repository_path.exists():
-            code_repository_path.mkdir(parents=True, exist_ok=True)
-        code_repository_operators_path = code_repository_path / "operators"
-        if not code_repository_operators_path.exists():
-            code_repository_operators_path.mkdir(parents=True, exist_ok=True)
-        code_repository_workflows_path = code_repository_path / "workflows"
-        if not code_repository_workflows_path.exists():
-            code_repository_workflows_path.mkdir(parents=True, exist_ok=True)
+        # Operators repository folders
+        operators_repository_path = base_path / "operators_repository"
+        if not operators_repository_path.exists():
+            operators_repository_path.mkdir(parents=True, exist_ok=True)
+        operators_repository_operators_path = operators_repository_path / "operators"
+        if not operators_repository_operators_path.exists():
+            operators_repository_operators_path.mkdir(parents=True, exist_ok=True)
+        operators_repository_workflows_path = operators_repository_path / "workflows"
+        if not operators_repository_workflows_path.exists():
+            operators_repository_workflows_path.mkdir(parents=True, exist_ok=True)
 
         # Datasets folder
         datasets_path = base_path / "datasets"
@@ -350,14 +426,16 @@ class CommandLineInterface:
             tmp_path.mkdir(parents=True, exist_ok=True)
         self.logger.info("Required folders created successfully!")
 
+
     def _create_dependencies_map(self, save_map_as_file: bool = True) -> None:
-        """Construct a map between Operators and unique definitions for docker images dependencies
+        """
+        Construct a map between Operators and unique definitions for docker images dependencies
 
         Args:
             save_map_as_file (bool, optional): Set if dependencies_map will be saved as file. Defaults to True.
 
         Raises:
-            ValueError: Raise if operators is not found in the code_repository
+            ValueError: Raise if operators is not found in the operators_repository
         """
         with open(self.organized_flowui_path / "compiled_metadata.json", "r") as f:
             compiled_metadata = json.load(f)
@@ -387,59 +465,14 @@ class CommandLineInterface:
                     }
 
         if not operators_images_map:
-            raise ValueError("No operators found in the code repository")
+            raise ValueError("No operators found in the Operators repository")
 
         if save_map_as_file:
             map_file_path = self.organized_flowui_path / "dependencies_map.json"
             with open(map_file_path, "w") as outfile:
                 json.dump(operators_images_map, outfile, indent=4)
 
-    def run_local_dev(self) -> None:
-        """Run FlowUI using local development environment scope.
-        This will create a docker-compose.yaml file and run it.
-        """ 
-        self._validate_project_structure()
-        if not os.environ.get('FLOWUI_PATH_HOST'):
-            os.environ['FLOWUI_PATH_HOST'] = str(Path('../flowui').resolve())
-        self._create_mnt_required_folders()
-        self.create_docker_compose_file(run_scope="local-dev")
-        self.docker = DockerClient(compose_files=["docker-compose.yaml"])
-        self.docker.compose.up()
 
-    def run(self) -> None:
-        """Run FlowUI using local deploy scope.
-        This will create a docker-compose.yaml file and run it.
-        """
-        self._validate_project_structure()
-        # Create necessary folders in user mount path
-        self._create_mnt_required_folders()
-        self.create_docker_compose_file()
-        self.docker = DockerClient(compose_files=["docker-compose.yaml"])
-        self.docker.compose.up()
-    
-    def run_operator_in_docker(self) -> None:
-        """Convenience function to run Operators within Docker images"""
-        self.logger.info("Running Operator...")
-        run_operator_in_docker()
-    
-    def run_operator_in_bash(self) -> None:
-        """Convenience function to run Operators from a bash script"""
-        self.logger.info("Running Operator...")
-        run_operator_in_bash()
-
-    def stop_compose(self) -> None:
-        """Stop FlowUI project. It will get the running docker compose and stop it."""
-        compose = Path("docker-compose.yaml")
-        if not compose.is_file():
-            raise Exception("docker-compose.yaml file not found")
-        try:
-            self.logger.info("Stopping docker-compose...")
-            self.docker = DockerClient(compose_files=["docker-compose.yaml"])
-            self.docker.compose.down()
-        except Exception as e: # work on python 3.x
-            self.logger.info('Failed to stop compose processes: '+ str(e))
-        # TODO - add docker stop and docker rm
-    
     def _create_compiled_operators_metadata(self) -> None:  
         """Create compiled metadata from Operators metadata.json files and include input_schema generated from models.py"""
         compiled_metadata = dict()
@@ -456,9 +489,10 @@ class CommandLineInterface:
                     metadata["name"] = operator_name
 
                 # Add input and output schemas
-                input_model_class, output_model_class = load_operator_models_from_path(operators_folder_path=str(self.operators_path), operator_name=op_dir.name)
+                input_model_class, output_model_class, secrets_model_class = load_operator_models_from_path(operators_folder_path=str(self.operators_path), operator_name=op_dir.name)
                 metadata["input_schema"] = input_model_class.schema()
                 metadata["output_schema"] = output_model_class.schema()
+                metadata["secrets_schema"] = secrets_model_class.schema() if secrets_model_class else None
 
                 # Add to compiled metadata
                 compiled_metadata[operator_name] = metadata
@@ -467,97 +501,140 @@ class CommandLineInterface:
         with open(str(self.organized_flowui_path / "compiled_metadata.json"), "w") as f:
             json.dump(compiled_metadata, f, indent=4)
 
-    def organize_project(self):
-        """Organize FlowUI project.
-        This will validate the project structure and user code repository, 
-        create the operators compiled_metadata.json and dependencies_map.json files.
-        """
-        self._validate_project_structure()
-        # Validate code repository folder
-        self._validate_code_repository()
-        # Create compiled metadata from Operators metadata.json files and add data input schema
-        self._create_compiled_operators_metadata()
-        # Generate dependencies_map.json file
-        self._create_dependencies_map(save_map_as_file=True)
 
-    def _create_config_toml(self, path: Path, project_name: str):
-        default_mount_path_host = Path.cwd() / f'{project_name}/mnt/fs'
-        data = {
-            "project": {
-                "PROJECT_NAME": project_name,
-                "FLOWUI_DEPLOY_MODE": "local-bash",
-                "VOLUME_MOUNT_PATH_HOST": str(default_mount_path_host),
-                "OPERATORS_SECRETS": []
-            },
-            "code-repository": {
-                "CODE_REPOSITORY_SOURCE": "local",
-                "GITHUB_REPOSITORY_NAME": ""
-            } 
-        }
-        with open(str(path / 'config.toml'), 'wb') as out:
-            tomli_w.dump(data, out)
+    def create_operators_repository(self) -> None:
+        """
+        Create a new Operators repository with folder structure and basic example files:
+
+        1. Create config.toml file
+        2. Create operators folder
+        3. Create dependencies folder
+        4. Create .flowui folder
+        5. Create example operators files
+        6. Create example dependency files
+        7. Run flowui organize
+        """
+        repository_name = input("Enter the repository's name: ") or f"new-repository-{str(uuid.uuid4())[0:8]}"
+        while not self._validate_repository_name(repository_name):
+            repository_name = input("\nInvalid repository name. Should have only numbers, letters, underscores and dashes. \nEnter a new repository name: ") or f"new-repository-{str(uuid.uuid4())[0:8]}"
+        cwd = Path.cwd()
+        repository_folder = cwd / repository_name
+        if repository_folder.is_dir():
+            raise Exception("Repository folder already exists")
+        repository_folder.mkdir()
+        self.logger.info(f"Creating repository in {repository_folder}")
+        self._create_config_toml(repository_path=repository_folder, repository_name=repository_name)
+        self._create_repository_folders(repository_folder)
+        subprocess.call(f"cd {str(repository_folder)} && flowui organize", shell=True)
+
 
     @staticmethod
-    def _validate_project_name(name: str):
+    def _validate_repository_name(name: str):
         regex = r'^[A-Za-z0-9_-]*$'
         pattern = re.compile(regex)
         if pattern.match(name):
             return True
         return False
 
-    def _create_new_project_folders(self, project_path: Path):
-        self.logger.info("Creating new project folders...")
-        import flowui.example_project as example_project
-        example_project_source_path = Path(os.path.dirname(example_project.__file__))
 
-        operators_dst_path = project_path / "operators"
+    def _create_config_toml(self, repository_path: Path, repository_name: str) -> None:
+        """
+        Create Operators repository basic config.toml file
+
+        Args:
+            path (Path): _description_
+            repository_name (str): _description_
+        """
+        default_mount_path_host = Path.cwd() / f'{repository_name}/mnt/fs'
+        data = {
+            "repository": {
+                "REPOSITORY_NAME": repository_name,
+                "FLOWUI_DEPLOY_MODE": "local-bash",
+                "VOLUME_MOUNT_PATH_HOST": str(default_mount_path_host),
+                "OPERATORS_SECRETS": [],
+                "OPERATORS_REPOSITORY_SOURCE": "local",
+                "GITHUB_REPOSITORY_NAME": ""
+            } 
+        }
+        with open(str(repository_path / 'config.toml'), 'wb') as out:
+            tomli_w.dump(data, out)
+
+
+    def _create_repository_folders(self, repository_path: Path) -> None:
+        """
+        _summary_
+
+        Args:
+            repository_path (Path): _description_
+        """
+        self.logger.info("Creating new repository folders...")
+        import flowui.example_repository as example_repository
+        example_repository_source_path = Path(os.path.dirname(example_repository.__file__))
+
+        operators_dst_path = repository_path / "operators"
         if not operators_dst_path.is_dir():
-            shutil.copytree(str(example_project_source_path / "operators"), str(operators_dst_path))
+            shutil.copytree(str(example_repository_source_path / "operators"), str(operators_dst_path))
 
-        flowui_path = project_path / ".flowui"
+        flowui_path = repository_path / ".flowui"
         if not flowui_path.is_dir():
-            shutil.copytree(str(example_project_source_path / ".flowui"), str(flowui_path))
+            shutil.copytree(str(example_repository_source_path / ".flowui"), str(flowui_path))
 
-        dependencies_path = project_path / 'dependencies'
+        dependencies_path = repository_path / 'dependencies'
         if not dependencies_path.is_dir():
-            shutil.copytree(str(example_project_source_path / 'dependencies'), str(dependencies_path))
+            shutil.copytree(str(example_repository_source_path / 'dependencies'), str(dependencies_path))
+    
+
+    def organize_operators_repository(self) -> None:
+        """
+        Organize Operator's repository for FlowUI.
+        This will validate the folder structure, and create the operators compiled_metadata.json and dependencies_map.json files.
+        """        
+        # Validate repository
+        self._validate_repository_structure()
+        self._validate_operators_repository()
+        
+        # Create compiled metadata from Operators metadata.json files and add data input schema
+        self._create_compiled_operators_metadata()
+        
+        # Generate dependencies_map.json file
+        self._create_dependencies_map(save_map_as_file=True)
+
+        # Build and publish the images
+        if self.args.build_images:
+            updated_dependencies_map = self._build_docker_images()
+            map_file_path = self.organized_flowui_path / "dependencies_map.json"
+            with open(map_file_path, "w") as outfile:
+                json.dump(updated_dependencies_map, outfile, indent=4)
 
 
-    def create_project(self):
-        """Create a new project"""
-        # What need for a project
-        # 1. Create config.toml file
-        # 2. Create operators folder
-        # 3. Create dependencies folder
-        # 4. Create .flowui folder
-        # 5. Create example operator file
-        # 6. Create example dependency file
-        project_name = input("Enter your project name: ") or "new-project"
-        while not self._validate_project_name(project_name):
-            project_name = input("\nInvalid project name. Should have only numbers, letters, underscores and dashes. \nEnter a new project name: ") or "new-project"
-        cwd = Path.cwd()
-        project_folder = cwd / project_name
-        if project_folder.is_dir():
-            raise Exception("Project folder already exists")
-        project_folder.mkdir()
-        self.logger.info(f"Creating project in {project_folder}")
-        self._create_config_toml(project_folder, project_name)
-        self._create_new_project_folders(project_folder)
-        subprocess.call(f"cd {str(project_folder)} && flowui organize", shell=True)
+    def run_operator_in_docker(self) -> None:
+        """Convenience function to run Operators within Docker images"""
+        self.logger.info("Running Operator...")
+        run_operator_in_docker()
+    
+
+    def run_operator_in_bash(self) -> None:
+        """Convenience function to run Operators from a bash script"""
+        self.logger.info("Running Operator...")
+        run_operator_in_bash()
 
 
 def cli():
     cli = CommandLineInterface()
     cli_args = cli.args
     cli_func_map = {        
-        "organize": cli.organize_project,
+        # Run locally
         "run": cli.run,
         "stop": cli.stop_compose,
-        "build-docker-images": cli.build_docker_images,
         "create-compose-file": cli.create_docker_compose_file,
         "run-local-dev": cli.run_local_dev,
+        
+        # Operator's repository
+        "create-operators-repository": cli.create_operators_repository,
+        "organize": cli.organize_operators_repository,
+        
+        # Run Operator
         "run-operator-docker": cli.run_operator_in_docker,
         "run-operator-bash": cli.run_operator_in_bash,
-        "create-project": cli.create_project
     }
     cli_func_map[cli_args.action]()
